@@ -9,6 +9,7 @@ import sys
 from gunicorn.app.base import Application
 from gunicorn import util
 
+
 def is_setting_mod(path):
     return (os.path.isfile(os.path.join(path, "settings.py")) or
             os.path.isfile(os.path.join(path, "settings.pyc")))
@@ -34,7 +35,7 @@ def find_settings_module(path):
             project_path = path
     elif os.path.isfile(path):
         project_path = os.path.dirname(path)
-        settings_name, _  = os.path.splitext(os.path.basename(path))
+        settings_name, _ = os.path.splitext(os.path.basename(path))
 
     return project_path, settings_name
 
@@ -54,7 +55,8 @@ def make_default_env(cfg):
         os.environ['DJANGO_SETTINGS_MODULE']
     except KeyError:
         # not settings env set, try to build one.
-        project_path, settings_name = find_settings_module(os.getcwd())
+        cwd = util.getcwd()
+        project_path, settings_name = find_settings_module(cwd)
 
         if not project_path:
             raise RuntimeError("django project not found")
@@ -91,7 +93,6 @@ class DjangoApplication(Application):
                         settings_name))
                 self.cfg.set("pythonpath", pythonpath)
 
-
     def load(self):
         # set settings
         make_default_env(self.cfg)
@@ -105,16 +106,15 @@ class DjangoApplicationCommand(Application):
 
     def __init__(self, options, admin_media_path):
         self.usage = None
+        self.prog = None
         self.cfg = None
         self.config_file = options.get("config") or ""
         self.options = options
         self.admin_media_path = admin_media_path
         self.callable = None
         self.project_path = None
-
         self.do_load_config()
 
-
     def init(self, *args):
         if 'settings' in self.options:
             self.options['django_settings'] = self.options.pop('settings')
@@ -133,10 +133,11 @@ class DjangoApplicationCommand(Application):
         mod = util.import_module("gunicorn.app.django_wsgi")
         return mod.make_command_wsgi_application(self.admin_media_path)
 
+
 def run():
     """\
     The ``gunicorn_django`` command line runner for launching Django
     applications.
     """
     from gunicorn.app.djangoapp import DjangoApplication
-    DjangoApplication("%prog [OPTIONS] [SETTINGS_PATH]").run()
+    DjangoApplication("%(prog)s [OPTIONS] [SETTINGS_PATH]").run()
