@@ -7,20 +7,21 @@ from __future__ import with_statement
 
 import errno
 import os
+import random
 import select
 import signal
 import sys
 import time
 import traceback
 
-
-from gunicorn.errors import HaltServer
+from gunicorn.errors import HaltServer, AppImportError
 from gunicorn.pidfile import Pidfile
-from gunicorn.sock import create_socket
+from gunicorn.sock import create_sockets
 from gunicorn import util
 
 from gunicorn import __version__, SERVER_SOFTWARE
 
+
 class Arbiter(object):
     """
     Arbiter maintain the workers processes alive. It launches or
@@ -33,9 +34,12 @@ class Arbiter(object):
     # this error code, the arbiter will terminate.
     WORKER_BOOT_ERROR = 3
 
+    # A flag indicating if an application failed to be loaded
+    APP_LOAD_ERROR = 4
+
     START_CTX = {}
 
-    LISTENER = None
+    LISTENERS = []
     WORKERS = {}
     PIPE = []
 
@@ -51,6 +55,7 @@ class Arbiter(object):
     def __init__(self, app):
         os.environ["SERVER_SOFTWARE"] = SERVER_SOFTWARE
 
+        self._num_workers = None
         self.setup(app)
 
         self.pidfile = None
@@ -58,16 +63,7 @@ class Arbiter(object):
         self.reexec_pid = 0
         self.master_name = "Master"
 
-        # get current path, try to use PWD env first
-        try:
-            a = os.stat(os.environ['PWD'])
-            b = os.stat(os.getcwd())
-            if a.ino == b.ino and a.dev == b.dev:
-                cwd = os.environ['PWD']
-            else:
-                cwd = os.getcwd()
-        except:
-            cwd = os.getcwd()
+        cwd = util.getcwd()
 
         args = sys.argv[:]
         args.insert(0, sys.executable)
@@ -79,6 +75,15 @@ class Arbiter(object):
             0: sys.executable
         }
 
+    def _get_num_workers(self):
+        return self._num_workers
+
+    def _set_num_workers(self, value):
+        old_value = self._num_workers
+        self._num_workers = value
+        self.cfg.nworkers_changed(self, value, old_value)
+    num_workers = property(_get_num_workers, _set_num_workers)
+
     def setup(self, app):
         self.app = app
         self.cfg = app.cfg
@@ -97,8 +102,6 @@ class Arbiter(object):
 
         if self.cfg.debug:
             self.log.debug("Current configuration:")
-
-
             for config, value in sorted(self.cfg.settings.items(),
                     key=lambda setting: setting[1]):
                 self.log.debug("  %s: %s", config, value.value)
@@ -120,12 +123,12 @@ class Arbiter(object):
             self.pidfile.create(self.pid)
         self.cfg.on_starting(self)
         self.init_signals()
-        if not self.LISTENER:
-            self.LISTENER = create_socket(self.cfg, self.log)
+        if not self.LISTENERS:
+            self.LISTENERS = create_sockets(self.cfg, self.log)
 
+        listeners_str = ",".join([str(l) for l in self.LISTENERS])
         self.log.debug("Arbiter booted")
-        self.log.info("Listening at: %s (%s)", self.LISTENER,
-            self.pid)
+        self.log.info("Listening at: %s (%s)", listeners_str, self.pid)
         self.log.info("Using worker: %s",
                 self.cfg.settings['worker_class'].get())
 
@@ -148,7 +151,7 @@ class Arbiter(object):
 
         self.log.close_on_exec()
 
-        # intialiatze all signals
+        # initialize all signals
         [signal.signal(s, self.signal) for s in self.SIGNALS]
         signal.signal(signal.SIGCHLD, self.handle_chld)
 
@@ -266,7 +269,7 @@ class Arbiter(object):
 
     def handle_winch(self):
         "SIGWINCH handling"
-        if os.getppid() == 1 or os.getpgrp() != os.getpid():
+        if self.cfg.daemon:
             self.log.info("graceful stop of workers")
             self.num_workers = 0
             self.kill_workers(signal.SIGQUIT)
@@ -313,7 +316,6 @@ class Arbiter(object):
         except KeyboardInterrupt:
             sys.exit()
 
-
     def stop(self, graceful=True):
         """\
         Stop workers
@@ -321,11 +323,7 @@ class Arbiter(object):
         :attr graceful: boolean, If True (the default) workers will be
         killed gracefully  (ie. trying to wait for the current connection)
         """
-        try:
-            self.LISTENER.close()
-        except Exception:
-            pass
-        self.LISTENER = None
+        self.LISTENERS = []
         sig = signal.SIGQUIT
         if not graceful:
             sig = signal.SIGTERM
@@ -348,11 +346,12 @@ class Arbiter(object):
             self.master_name = "Old Master"
             return
 
-        os.environ['GUNICORN_FD'] = str(self.LISTENER.fileno())
+        fds = [l.fileno() for l in self.LISTENERS]
+        os.environ['GUNICORN_FD'] = ",".join([str(fd) for fd in fds])
+
         os.chdir(self.START_CTX['cwd'])
         self.cfg.pre_exec(self)
-        util.closerange(3, self.LISTENER.fileno())
-        util.closerange(self.LISTENER.fileno()+1, util.get_maxfd())
+
         os.execvpe(self.START_CTX[0], self.START_CTX['args'], os.environ)
 
     def reload(self):
@@ -367,9 +366,11 @@ class Arbiter(object):
 
         # do we need to change listener ?
         if old_address != self.cfg.address:
-            self.LISTENER.close()
-            self.LISTENER = create_socket(self.cfg, self.log)
-            self.log.info("Listening at: %s", self.LISTENER)
+            # close all listeners
+            [l.close for l in self.LISTENERS]
+            # init new listeners
+            self.LISTENERS = create_sockets(self.cfg, self.log)
+            self.log.info("Listening at: %s", ",".join(str(self.LISTENERS)))
 
         # do some actions on reload
         self.cfg.on_reload(self)
@@ -427,6 +428,9 @@ class Arbiter(object):
                     if exitcode == self.WORKER_BOOT_ERROR:
                         reason = "Worker failed to boot."
                         raise HaltServer(reason, self.WORKER_BOOT_ERROR)
+                    if exitcode == self.APP_LOAD_ERROR:
+                        reason = "App failed to load."
+                        raise HaltServer(reason, self.APP_LOAD_ERROR)
                     worker = self.WORKERS.pop(wpid, None)
                     if not worker:
                         continue
@@ -451,8 +455,8 @@ class Arbiter(object):
 
     def spawn_worker(self):
         self.worker_age += 1
-        worker = self.worker_class(self.worker_age, self.pid, self.LISTENER,
-                                    self.app, self.timeout/2.0,
+        worker = self.worker_class(self.worker_age, self.pid, self.LISTENERS,
+                                    self.app, self.timeout / 2.0,
                                     self.cfg, self.log)
         self.cfg.pre_fork(self, worker)
         pid = os.fork()
@@ -470,6 +474,13 @@ class Arbiter(object):
             sys.exit(0)
         except SystemExit:
             raise
+        except AppImportError as e:
+            self.log.debug("Exception while loading the application: \n%s",
+                    traceback.format_exc())
+
+            sys.stderr.write("%s\n" % e)
+            sys.stderr.flush()
+            sys.exit(self.APP_LOAD_ERROR)
         except:
             self.log.exception("Exception in worker process:\n%s",
                     traceback.format_exc())
@@ -494,6 +505,7 @@ class Arbiter(object):
 
         for i in range(self.num_workers - len(self.WORKERS.keys())):
             self.spawn_worker()
+            time.sleep(0.1 * random.random())
 
     def kill_workers(self, sig):
         """\
