@@ -367,6 +367,12 @@ def validate_post_request(val):
     else:
         raise TypeError("Value must have an arity of: 4")
 
+def get_default_config_file():
+    config_path = os.path.join(os.path.abspath(os.getcwd()), 'gunicorn.conf.py')
+    if os.path.exists(config_path):
+        return config_path
+    return None
+
 
 class ConfigFile(Setting):
     name = "config"
@@ -382,7 +388,6 @@ class ConfigFile(Setting):
         application specific configuration.
         """
 
-
 class Bind(Setting):
     name = "bind"
     action = "append"
@@ -1162,6 +1167,24 @@ class Postfork(Setting):
         """
 
 
+class PostWorkerInit(Setting):
+    name = "post_worker_init"
+    section = "Server Hooks"
+    validator = validate_callable(1)
+    type = six.callable
+
+    def post_worker_init(worker):
+        pass
+
+    default = staticmethod(post_worker_init)
+    desc = """\
+        Called just after a worker has initialized the application.
+
+        The callable needs to accept one instance variable for the initialized
+        Worker.
+        """
+
+
 class PreExec(Setting):
     name = "pre_exec"
     section = "Server Hooks"
