@@ -8,8 +8,7 @@ import os
 import re
 import sys
 
-from gunicorn.six import (unquote, string_types, binary_type, reraise,
-        text_type)
+from gunicorn.six import unquote_to_wsgi_str, string_types, binary_type, reraise
 from gunicorn import SERVER_SOFTWARE
 import gunicorn.util as util
 
@@ -98,7 +97,7 @@ def create(req, sock, client, server, cfg):
         if hdr_name == "EXPECT":
             # handle expect
             if hdr_value.lower() == "100-continue":
-                sock.send("HTTP/1.1 100 Continue\r\n\r\n")
+                sock.send(b"HTTP/1.1 100 Continue\r\n\r\n")
         elif x_forwarded_for_header and hdr_name == x_forwarded_for_header:
             forward = hdr_value
         elif secure_headers and (hdr_name.upper() in secure_headers and
@@ -164,7 +163,7 @@ def create(req, sock, client, server, cfg):
     path_info = req.path
     if script_name:
         path_info = path_info.split(script_name, 1)[1]
-    environ['PATH_INFO'] = unquote(path_info)
+    environ['PATH_INFO'] = unquote_to_wsgi_str(path_info)
     environ['SCRIPT_NAME'] = script_name
 
     environ.update(proxy_environ(req))
@@ -280,9 +279,6 @@ class Response(object):
     def write(self, arg):
         self.send_headers()
 
-        if isinstance(arg, text_type):
-            arg = arg.encode('utf-8')
-
         assert isinstance(arg, binary_type), "%r is not a byte." % arg
 
         arglen = len(arg)
