@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -
 #
-# This file is part of gunicorn released under the MIT license. 
+# This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
 from __future__ import with_statement
@@ -20,7 +20,7 @@ class Pidfile(object):
     def __init__(self, fname):
         self.fname = fname
         self.pid = None
-        
+
     def create(self, pid):
         oldpid = self.validate()
         if oldpid:
@@ -30,35 +30,38 @@ class Pidfile(object):
                 "(or pid file '%s' is stale)" % (os.getpid(), self.fname))
 
         self.pid = pid
-        
+
         # Write pidfile
         fdir = os.path.dirname(self.fname)
-        if not os.path.isdir(fdir):
+        if fdir and not os.path.isdir(fdir):
             raise RuntimeError("%s doesn't exist. Can't create pidfile." % fdir)
         fd, fname = tempfile.mkstemp(dir=fdir)
-        os.write(fd, "%s\n" % self.pid)
+        os.write(fd, ("%s\n" % self.pid).encode('utf-8'))
         if self.fname:
             os.rename(fname, self.fname)
         else:
             self.fname = fname
         os.close(fd)
-        
+
+        # set permissions to -rw-r--r--
+        os.chmod(self.fname, 420)
+
     def rename(self, path):
         self.unlink()
         self.fname = path
         self.create(self.pid)
-        
+
     def unlink(self):
         """ delete pidfile"""
         try:
             with open(self.fname, "r") as f:
-                pid1 =  int(f.read() or 0)
+                pid1 = int(f.read() or 0)
 
             if pid1 == self.pid:
                 os.unlink(self.fname)
         except:
             pass
-       
+
     def validate(self):
         """ Validate pidfile and make it stale if needed"""
         if not self.fname:
@@ -73,11 +76,11 @@ class Pidfile(object):
                 try:
                     os.kill(wpid, 0)
                     return wpid
-                except OSError, e:
-                    if e[0] == errno.ESRCH:
+                except OSError as e:
+                    if e.args[0] == errno.ESRCH:
                         return
                     raise
-        except IOError, e:
-            if e[0] == errno.ENOENT:
+        except IOError as e:
+            if e.args[0] == errno.ENOENT:
                 return
             raise
