@@ -110,7 +110,7 @@ class GeventWorker(AsyncWorker):
 
             # Force kill all active the handlers
             self.log.warning("Worker graceful timeout (pid:%s)" % self.pid)
-            server.stop(timeout=1)
+            [server.stop(timeout=1) for server in servers]
         except:
             pass
 
