@@ -5,5 +5,5 @@ request = {
     "headers": [
         ("ACCEPT", "*/*")
     ],
-    "body": ""
-}
\ No newline at end of file
+    "body": b""
+}
